Use video capture intent quality when recording with effects.

Previously, effects always used 480p quality. When used for messaging,
the intent requests a lower quality, and it needs to be used instead.

Bug: 5465146
Change-Id: Ib2ae772de35ad84b8c19f961c71fd9ae43dd4426
diff --git a/src/com/android/camera/VideoCamera.java b/src/com/android/camera/VideoCamera.java
index 6a251d4..353b540 100755
--- a/src/com/android/camera/VideoCamera.java
+++ b/src/com/android/camera/VideoCamera.java
@@ -723,8 +723,10 @@
                         null);
                 }
             } else {
-                // Set quality to 480p for effects
-                quality = CamcorderProfile.QUALITY_480P;
+                // Set quality to 480p for effects, unless intent is overriding it
+                if (!intent.hasExtra(MediaStore.EXTRA_VIDEO_QUALITY)) {
+                    quality = CamcorderProfile.QUALITY_480P;
+                }
                 // On initial startup, can get here before indicator control is
                 // enabled. In that case, UI quality override handled in
                 // initializeIndicatorControl.